==> camel-k-model-v1-6.1.0-sources.jar: io/fabric8/camelk/v1/IntegrationListFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IntegrationListFluent<A extends IntegrationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Integration item);
  public A setToItems(Integer index,Integration item);
  public A addToItems(io.fabric8.camelk.v1.Integration... items);
  public A addAllToItems(Collection<Integration> items);
  public A removeFromItems(io.fabric8.camelk.v1.Integration... items);
  public A removeAllFromItems(Collection<Integration> items);
  public A removeMatchingFromItems(Predicate<IntegrationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Integration> getItems();
  public List<Integration> buildItems();
  public Integration buildItem(Integer index);
  public Integration buildFirstItem();
  public Integration buildLastItem();
  public Integration buildMatchingItem(Predicate<IntegrationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<IntegrationBuilder> predicate);
  public A withItems(List<Integration> items);
  public A withItems(io.fabric8.camelk.v1.Integration... items);
  public Boolean hasItems();
  public IntegrationListFluent.ItemsNested<A> addNewItem();
  public IntegrationListFluent.ItemsNested<A> addNewItemLike(Integration item);
  public IntegrationListFluent.ItemsNested<A> setNewItemLike(Integer index,Integration item);
  public IntegrationListFluent.ItemsNested<A> editItem(Integer index);
  public IntegrationListFluent.ItemsNested<A> editFirstItem();
  public IntegrationListFluent.ItemsNested<A> editLastItem();
  public IntegrationListFluent.ItemsNested<A> editMatchingItem(Predicate<IntegrationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,IntegrationFluent<IntegrationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/IntegrationListFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IntegrationListFluent<A extends IntegrationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Integration item);
  public A setToItems(int index,Integration item);
  public A addToItems(io.fabric8.camelk.v1.Integration... items);
  public A addAllToItems(Collection<Integration> items);
  public A removeFromItems(io.fabric8.camelk.v1.Integration... items);
  public A removeAllFromItems(Collection<Integration> items);
  public A removeMatchingFromItems(Predicate<IntegrationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Integration> getItems();
  public List<Integration> buildItems();
  public Integration buildItem(int index);
  public Integration buildFirstItem();
  public Integration buildLastItem();
  public Integration buildMatchingItem(Predicate<IntegrationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<IntegrationBuilder> predicate);
  public A withItems(List<Integration> items);
  public A withItems(io.fabric8.camelk.v1.Integration... items);
  public Boolean hasItems();
  public IntegrationListFluent.ItemsNested<A> addNewItem();
  public IntegrationListFluent.ItemsNested<A> addNewItemLike(Integration item);
  public IntegrationListFluent.ItemsNested<A> setNewItemLike(int index,Integration item);
  public IntegrationListFluent.ItemsNested<A> editItem(int index);
  public IntegrationListFluent.ItemsNested<A> editFirstItem();
  public IntegrationListFluent.ItemsNested<A> editLastItem();
  public IntegrationListFluent.ItemsNested<A> editMatchingItem(Predicate<IntegrationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,IntegrationFluent<IntegrationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
